package org.pfsw.tools.cda.base.model.util;

import static org.junit.Assert.*;

import org.junit.Test;
import org.pfsw.tools.cda.base.testhelper.UnitTestHelper;

public class StringFilterCollectionTest
{
  @Test
  public void test_matches()
  {
    StringFilterCollection filters = UnitTestHelper.createSample1();
    
    assertFalse(filters.matches(null));
    assertFalse(filters.matches(""));
    assertTrue(filters.matches("org.pfsw.tools.urutu.Main"));
    assertTrue(filters.matches("org.pfsw.tools.Safe"));
    assertTrue(filters.matches("org.apache.commons.StringUtils"));
    assertFalse(filters.matches("org.pfsw.text.StringPattern"));
    assertFalse(filters.matches("org.apache.codec.CryptUtils"));
  }

  @Test
  public void test_getFilterAt()
  {
    StringFilterCollection filters = UnitTestHelper.createSample2();
    
    assertEquals("org.omg.*", filters.getFilterAt(3).getPattern());
    assertEquals("java.*", filters.getFilterAt(5).getPattern());
  }
  
  @Test
  public void test_setFilterAt()
  {
    StringFilterCollection filters = UnitTestHelper.createSample2();
    
    assertTrue(filters.matches("org.omg.Test"));
    assertFalse(filters.matches("org.samples.Test"));
    assertEquals("org.omg.*", filters.getFilterAt(3).getPattern());
    filters.setFilterAt(3, new StringFilter("org.samples.*"));
    assertFalse(filters.matches("org.omg.Test"));
    assertTrue(filters.matches("org.samples.Test"));
    assertEquals("org.samples.*", filters.getFilterAt(3).getPattern());
  }
  
  @Test
  public void test_remove()
  {
    StringFilterCollection filters = UnitTestHelper.createSample2();
    StringFilter stringFilter = new StringFilter("org.xml.sax.*");
    
    assertTrue(filters.contains(stringFilter));
    assertTrue(filters.remove(stringFilter));
    assertFalse(filters.contains(stringFilter));
  }
  
  @Test
  public void test_getFilters()
  {
    StringFilterCollection filters = UnitTestHelper.createSample1();
    StringFilter[] stringFilters;
    
    stringFilters = filters.getFilters();
    assertEquals(2, stringFilters.length);
    assertEquals("org.pfsw.tools.*", stringFilters[0].getPattern());
    assertEquals("org.apache.commons.*", stringFilters[1].getPattern());
  }
  
  @Test
  public void test_isEqual_true()
  {
    StringFilterCollection filters1 = UnitTestHelper.createSample2();
    StringFilterCollection filters2 = UnitTestHelper.createSample2();

    assertTrue(filters1.isEqual(filters2));
  }
  
  @Test
  public void test_isEqual_false()
  {
    StringFilterCollection filters1 = UnitTestHelper.createSample2();
    StringFilterCollection filters2 = UnitTestHelper.createSample2();
    
    assertTrue(filters2.remove(new StringFilter("com.sun.*")));
    assertFalse(filters1.isEqual(filters2));
    filters2 = UnitTestHelper.createSample2();
    filters2.setFilterAt(5, new StringFilter("net.samples.*"));
    assertFalse(filters1.isEqual(filters2));
  }
  
  @Test
  public void test_isEqual_copy()
  {
    StringFilterCollection filters1 = UnitTestHelper.createSample2();
    StringFilterCollection filters2 = filters1.copy();
    
    assertTrue(filters1.isEqual(filters2));
    assertEquals("org.xml.sax.*", filters1.getFilterAt(2).getPattern());
    assertEquals("org.xml.sax.*", filters2.getFilterAt(2).getPattern());
    filters2.setFilterAt(2, new StringFilter("net.samples.*"));
    assertEquals("org.xml.sax.*", filters1.getFilterAt(2).getPattern());
    assertEquals("net.samples.*", filters2.getFilterAt(2).getPattern());
  }
  
  @Test
  public void test_matches_with_exclude_filters()
  {
    StringFilterCollection filters = UnitTestHelper.createSample3();
    
    assertFalse(filters.matches(null));
    assertFalse(filters.matches(""));
    assertTrue(filters.matches("javax.activation.FileFilter"));
    assertFalse(filters.matches("javax.ws.rs.core.Request"));
    assertTrue(filters.matches("org.apache.commons.logging.LogFactory"));
    assertFalse(filters.matches("org.apache.commons.lang.CharUtils"));
  }
  
  @Test
  public void test_matchesNone_with_exclude_filters()
  {
    StringFilterCollection filters = UnitTestHelper.createSample3();
    
    assertTrue(filters.matchesNone(null));
    assertTrue(filters.matchesNone(""));
    assertFalse(filters.matchesNone("javax.activation.FileFilter"));
    assertTrue(filters.matchesNone("javax.ws.rs.core.Request"));
    assertFalse(filters.matchesNone("org.apache.commons.logging.LogFactory"));
    assertTrue(filters.matchesNone("org.apache.commons.lang.CharUtils"));
  }
  
  @Test
  public void test_reset()
  {
    StringFilterCollection filters = UnitTestHelper.createSample3();
    
    assertFalse(filters.isEmpty());
    assertEquals(9, filters.size());

    filters.reset();
    
    assertTrue(filters.isEmpty());
    assertEquals(0, filters.size());
  }
}