package org.pfsw.tools.cda.base.model.util;

import static org.junit.Assert.*;

import org.junit.Test;
import org.pfsw.bif.text.IStringFilter;

public class StringFilterTest
{
  @Test
  public void test_matches_active()
  {
    StringFilter filter = new StringFilter("org.samples.*");
    
    assertTrue(filter.matches("org.samples.Test"));
    assertTrue(filter.matches("org.samples.sub.section.Plain"));
    assertFalse(filter.matches("com.samples.Test"));
    assertFalse(filter.matches("org.samplesTest"));
  }

  @Test
  public void test_matches_inactive()
  {
    StringFilter filter = new StringFilter("org.samples.*");
    
    filter.setActive(false);
    assertFalse(filter.matches("org.samples.Test"));
    assertFalse(filter.matches("org.samples.sub.section.Plain"));
    assertFalse(filter.matches("com.samples.Test"));
    assertFalse(filter.matches("org.samplesTest"));
  }

  @Test
  public void test_matches_active_excluded()
  {
    StringFilter filter = new StringFilter("org.samples.*");
    
    filter.setExclude(true);
    assertTrue(filter.matches("org.samples.Test"));
    assertTrue(filter.matches("org.samples.sub.section.Plain"));
    assertFalse(filter.matches("com.samples.Test"));
    assertFalse(filter.matches("org.samplesTest"));
  }
  
  @Test
  public void test_matches_file_pattern()
  {
    IStringFilter filter = new StringFilter("edu/umd/cs/findbugs/FindBugsAnnotationDescriptions*.properties");
    
    assertTrue(filter.matches("edu/umd/cs/findbugs/FindBugsAnnotationDescriptions_ja.properties"));
    assertTrue(filter.matches("edu/umd/cs/findbugs/FindBugsAnnotationDescriptions.properties"));
    assertFalse(filter.matches("edu/umd/cs/findbugs/gui/bundle/findbugs_de.properties"));
  }  
}