package org.pfsw.tools.cda.base.testhelper;

import java.io.File;

import org.pfsw.tools.cda.base.model.ClassContainer;
import org.pfsw.tools.cda.base.model.ClassPackage;
import org.pfsw.tools.cda.base.model.ClassSpace;
import org.pfsw.tools.cda.base.model.Workset;
import org.pfsw.tools.cda.base.model.container.ContainerSpecification;
import org.pfsw.tools.cda.base.model.util.StringFilter;
import org.pfsw.tools.cda.base.model.util.StringFilterCollection;

public class UnitTestHelper
{
  public static final String TESTDATA_DIR = "./testdata/";
  public static final String LIB_DIR_1 = TESTDATA_DIR + "lib1/";
  
  public static StringFilterCollection createSample1()
  {
    StringFilterCollection filters = new StringFilterCollection();
    
    filters.add(new StringFilter("org.pfsw.tools.*"));
    filters.add(new StringFilter("org.apache.commons.*"));

    return filters;
  }

  public static StringFilterCollection createSample2()
  {
    StringFilterCollection filters = new StringFilterCollection();
    
    filters.add(new StringFilter("org.pfsw.tools.*"));
    filters.add(new StringFilter("org.apache.commons.*"));
    filters.add(new StringFilter("org.xml.sax.*"));
    filters.add(new StringFilter("org.omg.*"));
    filters.add(new StringFilter("com.sun.*"));
    filters.add(new StringFilter("java.*"));
    filters.add(new StringFilter("javax.*"));
    
    return filters;
  }
  
  public static StringFilterCollection createSample3()
  {
    StringFilterCollection filters;
    StringFilter excludeFilter;
    
    filters = createSample2();

    excludeFilter = new StringFilter("org.apache.commons.lang.*");
    excludeFilter.setExclude(true);
    filters.add(excludeFilter);
    
    excludeFilter = new StringFilter("javax.ws.rs.*");
    excludeFilter.setExclude(true);
    filters.add(excludeFilter);
    
    return filters;
  }
  
  public static Workset createWorkset1()
  {
    String containerName1 = LIB_DIR_1 + "pf-db-3.0.0.jar";
    Workset workset;
    ClassSpace classSpace;
    ContainerSpecification containerSpec;
    ClassContainer classContainer;
    ClassPackage classPackage;
    
    workset = new Workset("UnitTest-Workset");
    classSpace = new ClassSpace(workset);
    workset.setClassSpaceAndFactory(classSpace);
    containerSpec = new ContainerSpecification(containerName1);
    containerSpec.setFileRepresentation(new File(containerName1));
    classContainer = new ClassContainer(containerSpec, workset);
    classSpace.addClassContainer(classContainer);

    classPackage = classContainer.createPackage("org.pfsw.db");
    classPackage.createClassInfo("org.pfsw.db.LoggerProvider");

    classPackage = classContainer.createPackage("org.pfsw.db.util");
    classPackage.createClassInfo("org.pfsw.db.utilDataSourceProxy");
    classPackage.createClassInfo("org.pfsw.db.util.DBUtil");

    classSpace.createClassInfo("org.pfsw.unknown.Unknown1", null);
    classSpace.getClassInfo("org.pfsw.others.Unknown2");  // Creates it in the NotFoundContainer
    classContainer.packagesCollected(true);
    return workset;
  }
}
