package org.pfsw.tools.cda.base.util;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.hamcrest.BaseMatcher;
import org.hamcrest.Description;
import org.hamcrest.Matcher;
import org.junit.Test;

public class PrioritySorterTest
{
  @Test
  public void test_sortAscending()
  {
    PrioritySorter<String> sorter = new PrioritySorter<String>();
    List<String> list;
    
    //@formatter:off
    sorter.add("omega", 5)
          .add("kappa", 10)
          .add("rho", 15)
          .add("gamma", 200);
    //@formatter:on
    
    list = sorter.sortAscending(sampleCollection1());
    
    assertThat(list, hasExactItems("omega", "kappa", "rho", "alpha", "lambda", "delta", "beta", "epsilon", "pi", "zeta", "eta", "omikron", "tau", "gamma"));
  }

  @Test
  public void test_sortDecending()
  {
    PrioritySorter<String> sorter;
    List<String> list;
    
    //@formatter:off
    sorter = PrioritySorter.<String>create()
        .setDefaultPriority(20)
        .add("omega", 5)
        .add("kappa", 10)
        .add("delta", 23756)
        .add("rho", 25)
        .add("beta", 1)
        .add("eta", 200);
    //@formatter:on
    
    list = sorter.sortDescending(sampleCollection1());
    
    assertThat(list, hasExactItems("delta", "eta", "rho", "tau", "omikron", "zeta", "pi", "epsilon", "lambda", "gamma", "alpha", "kappa", "omega", "beta"));
  }
  
  // ============== helper methods ==============
  private List<String> sampleCollection1()
  {
    List<String> data = new ArrayList<String>();
    
    data.add("alpha");
    data.add("gamma");
    data.add("kappa");
    data.add("omega");
    data.add("lambda");
    data.add("delta");
    data.add("beta");
    data.add("epsilon");
    data.add("pi");
    data.add("zeta");
    data.add("rho");
    data.add("eta");
    data.add("omikron");
    data.add("tau");
    return data;
  }

  @SafeVarargs
  private final <E> Matcher<List<E>> hasExactItems(final E...objects)
  {
    return new BaseMatcher<List<E>>()
    {
      private String errorInfo;
      
      @SuppressWarnings("unchecked")
      @Override
      public boolean matches(Object item)
      {
        if (!(item instanceof List))
        {
          errorInfo = "The provided item is no List";
          return false;          
        }
        List<E> valueList = (List<E>)item;
        if (valueList.size() != objects.length)
        {
          errorInfo = String.format("The provided list has %d elements, but expected was %d", valueList.size(), objects.length);          
          return false;          
        }
        for (int index = 0; index < objects.length; index++)
        {
          if (!valueList.get(index).equals(objects[index]))
          {
            errorInfo = String.format("Mismatch: '%s'%n", valueList.get(index));
            return false;          
          }          
        }
        return true;
      }
      
      @Override
      public void describeTo(Description description)
      {
        System.out.println(errorInfo);
        description.appendText(Arrays.toString(objects));
      }
    };
  }
}